@@ -1,9 +1,10 @@
 #' Clean TAF Directories
 #'
-#' Remove directories \file{db}, \file{input}, \file{model}, \file{output}, and
-#' \file{upload}.
+#' Remove TAF directories: \verb{data}, \verb{input}, \verb{model},
+#' \verb{output}, \verb{report}.
 #'
 #' @param path location where directories are found.
+#' @param also vector of additional directories to remove.
 #'
 #' @note
 #' The purpose of removing the directories is to make sure that subsequent TAF
@@ -12,7 +13,7 @@
 #' @seealso
 #' \code{\link{sourceTAF}} runs a TAF script.
 #'
-#' \code{\link{sourceAtoZ}} runs all TAF scripts in a directory.
+#' \code{\link{sourceAll}} runs all TAF scripts in a directory.
 #'
 #' \code{\link{icesTAF-package}} gives an overview of the package.
 #'
@@ -23,9 +24,10 @@
 #'
 #' @export
 
-clean <- function(path=".")
+clean <- function(path=".", also=NULL)
 {
   owd <- setwd(path)
   on.exit(setwd(owd))
-  unlink(c("db","input","model","output","upload"), recursive=TRUE)
+  dirs <- c("data", "input", "model", "output", "report", also)
+  unlink(dirs, recursive=TRUE)
 }
