@@ -14,13 +14,13 @@
 #' @seealso
 #' \code{\link{sourceTAF}} runs a TAF script.
 #'
-#' \code{\link{sourceAtoZ}} runs all TAF scripts in a directory.
+#' \code{\link{sourceAll}} runs all TAF scripts in a directory.
 #'
 #' \code{\link{icesTAF-package}} gives an overview of the package.
 #'
 #' @examples
 #' \dontrun{
-#' make("model.R", "input/input.txt", "model/results.txt")
+#' make("model.R", "input/input.dat", "model/results.dat")
 #' }
 #'
 #' @export
@@ -32,7 +32,7 @@ make <- function(recipe, prereq, target, debug=FALSE)
                      File=c(target,prereq),
                      Modified=file.mtime(c(target,prereq))))
   if(!all(file.exists(prereq)))
-    stop("Missing prerequisite file: ", prereq[!file.exists(prereq)][1])
+    stop("missing prerequisite file '", prereq[!file.exists(prereq)][1], "'")
   if(!file.exists(target) || file.mtime(target) < max(file.mtime(prereq)))
   {
     sourceTAF(recipe)
